summaryrefslogtreecommitdiffstats
path: root/Http/Authentication
diff options
context:
space:
mode:
Diffstat (limited to 'Http/Authentication')
-rw-r--r--Http/Authentication/AuthenticationFailureHandlerInterface.php6
-rw-r--r--Http/Authentication/AuthenticationSuccessHandlerInterface.php6
2 files changed, 6 insertions, 6 deletions
diff --git a/Http/Authentication/AuthenticationFailureHandlerInterface.php b/Http/Authentication/AuthenticationFailureHandlerInterface.php
index b35c232..e2d8eb2 100644
--- a/Http/Authentication/AuthenticationFailureHandlerInterface.php
+++ b/Http/Authentication/AuthenticationFailureHandlerInterface.php
@@ -2,7 +2,7 @@
namespace Symfony\Component\Security\Http\Authentication;
-use Symfony\Component\HttpKernel\Event\GetResponseEventArgs;
+use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\Security\Core\Exception\AuthenticationException;
use Symfony\Component\HttpFoundation\Request;
@@ -22,12 +22,12 @@ interface AuthenticationFailureHandlerInterface
* called by authentication listeners inheriting from
* AbstractAuthenticationListener.
*
* @param GetResponseEventArgs $eventArgs the "onCoreSecurity" event, this event always
* has the kernel as target
* @param Request $request
* @param AuthenticationException $exception
*
* @return Response the response to return
*/
- function onAuthenticationFailure(GetResponseEventArgs $eventArgs, Request $request, AuthenticationException $exception);
+ function onAuthenticationFailure(GetResponseEvent $event, Request $request, AuthenticationException $exception);
} \ No newline at end of file
@@ -22,12 +22,12 @@ interface AuthenticationFailureHandlerInterface
* AbstractAuthenticationListener.
*
- * @param GetResponseEventArgs $eventArgs the "onCoreSecurity" event, this event always
+ * @param GetResponseEvent $event the "onCoreSecurity" event, this event always
* has the kernel as target
* @param Request $request
diff --git a/Http/Authentication/AuthenticationSuccessHandlerInterface.php b/Http/Authentication/AuthenticationSuccessHandlerInterface.php
index 30b5e26..d7f8488 100644
--- a/Http/Authentication/AuthenticationSuccessHandlerInterface.php
+++ b/Http/Authentication/AuthenticationSuccessHandlerInterface.php
@@ -2,7 +2,7 @@
namespace Symfony\Component\Security\Http\Authentication;
-use Symfony\Component\HttpKernel\Event\GetResponseEventArgs;
+use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\HttpFoundation\Request;
@@ -22,12 +22,12 @@ interface AuthenticationSuccessHandlerInterface
* is called by authentication listeners inheriting from
* AbstractAuthenticationListener.
*
* @param GetResponseEventArgs $eventArgs the "onCoreSecurity" event, this event always
* has the kernel as target
* @param Request $request
* @param TokenInterface $token
*
* @return Response the response to return
*/
- function onAuthenticationSuccess(GetResponseEventArgs $eventArgs, Request $request, TokenInterface $token);
+ function onAuthenticationSuccess(GetResponseEvent $event, Request $request, TokenInterface $token);
} \ No newline at end of file
@@ -22,12 +22,12 @@ interface AuthenticationSuccessHandlerInterface
* AbstractAuthenticationListener.
*
- * @param GetResponseEventArgs $eventArgs the "onCoreSecurity" event, this event always
+ * @param GetResponseEvent $event the "onCoreSecurity" event, this event always
* has the kernel as target
* @param Request $request